@@ -16,7 +16,11 @@
 #' @export
 
 
-read_folder <- function(folder=".", read=read.delim, ...) {
+read_folder <- function(folder=try(file.choose(), silent=TRUE), read=read.delim, ...) {
+
+	if (class(folder)!="try-error") {
+
+	folder <- dirname(folder)
 
 	lf <- list.files(folder)
 	
@@ -45,5 +49,6 @@ read_folder <- function(folder=".", read=read.delim, ...) {
 		print("No file in folder/directory or folder/directory does not exist")
 		return(NULL)
 	}
+	}
 
 }
